summaryrefslogtreecommitdiffstats
path: root/tdeio/tdefile/kurlbar.h
diff options
context:
space:
mode:
Diffstat (limited to 'tdeio/tdefile/kurlbar.h')
-rw-r--r--tdeio/tdefile/kurlbar.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/tdeio/tdefile/kurlbar.h b/tdeio/tdefile/kurlbar.h
index 32c05ec58..7470ec82a 100644
--- a/tdeio/tdefile/kurlbar.h
+++ b/tdeio/tdefile/kurlbar.h
@@ -483,14 +483,14 @@ class TQDragObject;
class KURLBarToolTip;
/**
* This is the listbox used in KURLBar. It is a subclass of KListBox to support
* drag & drop and to set up the row / column mode.
*
* The widget has just one row or one column, depending on orientation().
*
* @author Carsten Pfeiffer <pfeiffer@kde.org>
*/
-class TDEIO_EXPORT KURLBarListBox : public KListBox
+class TDEIO_EXPORT KURLBarListBox : public TDEListBox
{
Q_OBJECT
@@ -483,14 +483,14 @@ class TQDragObject;
class KURLBarToolTip;
/**
- * This is the listbox used in KURLBar. It is a subclass of KListBox to support
+ * This is the listbox used in KURLBar. It is a subclass of TDEListBox to support
* drag & drop and to set up the row / column mode.
*